<!doctype html>
<html>
    <head>
        <title>Articles</title>
    </head>
    <body>
        <h1>Articles</h1>
        <a href="{% url 'article_create' %}">Create New Article</a>
        <ul>
            {% for article in articles %}
            <li>
                <a href="{% url 'article_detail' article.pk %}"
                    >{{ article.title }}</a
                >
            </li>
            {% empty %}
            <li>No articles yet.</li>
            {% endfor %}
        </ul>
    </body>
</html>
