# Generated by Django 5.2.6 on 2025-09-13 09:03

import quillsafe.fields
from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Article",
            fields=[
                ("id", models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("title", models.CharField(max_length=255)),
                ("content", quillsafe.fields.QuillField()),
            ],
        ),
    ]
